@@ -1,22 +1,17 @@
-from __future__ import absolute_import, unicode_literals
-
 import abc
 import logging
 import os
-
-from six import add_metaclass
+from pathlib import Path
 
 from virtualenv.create.describe import PosixSupports, WindowsSupports
 from virtualenv.create.via_global_ref.builtin.ref import PathRefToDest
-from virtualenv.util.path import Path
 
 from ..python2.python2 import Python2
 from .common import PyPy
 
 
-@add_metaclass(abc.ABCMeta)
-class PyPy2(PyPy, Python2):
-    """ """
+class PyPy2(PyPy, Python2, metaclass=abc.ABCMeta):
+    """PyPy 2"""
 
     @classmethod
     def exe_stem(cls):
@@ -24,8 +19,7 @@ class PyPy2(PyPy, Python2):
 
     @classmethod
     def sources(cls, interpreter):
-        for src in super(PyPy2, cls).sources(interpreter):
-            yield src
+        yield from super().sources(interpreter)
         # include folder needed on Python 2 as we don't have pyenv.cfg
         host_include_marker = cls.host_include_marker(interpreter)
         if host_include_marker.exists():
@@ -46,7 +40,7 @@ class PyPy2(PyPy, Python2):
     @classmethod
     def modules(cls):
         # pypy2 uses some modules before the site.py loads, so we need to include these too
-        return super(PyPy2, cls).modules() + [
+        return super().modules() + [
             "os",
             "copy_reg",
             "genericpath",
@@ -61,7 +55,7 @@ class PyPy2(PyPy, Python2):
         return self.dest / "lib_pypy"
 
     def ensure_directories(self):
-        dirs = super(PyPy2, self).ensure_directories()
+        dirs = super().ensure_directories()
         dirs.add(self.lib_pypy)
         host_include_marker = self.host_include_marker(self.interpreter)
         if host_include_marker.exists():
@@ -76,7 +70,7 @@ class PyPy2(PyPy, Python2):
         PyPy2 built-in imports are handled by this path entry, don't overwrite to not disable it
         see: https://github.com/pypa/virtualenv/issues/1652
         """
-        return 'or path.endswith("lib_pypy{}__extensions__") # PyPy2 built-in import marker'.format(os.sep)
+        return f'or path.endswith("lib_pypy{os.sep}__extensions__") # PyPy2 built-in import marker'
 
 
 class PyPy2Posix(PyPy2, PosixSupports):
@@ -84,11 +78,11 @@ class PyPy2Posix(PyPy2, PosixSupports):
 
     @classmethod
     def modules(cls):
-        return super(PyPy2Posix, cls).modules() + ["posixpath"]
+        return super().modules() + ["posixpath"]
 
     @classmethod
-    def _shared_libs(cls):
-        return ["libpypy-c.so", "libpypy-c.dylib"]
+    def _shared_libs(cls, python_dir):
+        return python_dir.glob("libpypy*.*")
 
     @property
     def lib(self):
@@ -96,8 +90,7 @@ class PyPy2Posix(PyPy2, PosixSupports):
 
     @classmethod
     def sources(cls, interpreter):
-        for src in super(PyPy2Posix, cls).sources(interpreter):
-            yield src
+        yield from super().sources(interpreter)
         host_lib = Path(interpreter.system_prefix) / "lib"
         if host_lib.exists():
             yield PathRefToDest(host_lib, dest=lambda self, _: self.lib)
@@ -108,14 +101,24 @@ class Pypy2Windows(PyPy2, WindowsSupports):
 
     @classmethod
     def modules(cls):
-        return super(Pypy2Windows, cls).modules() + ["ntpath"]
+        return super().modules() + ["ntpath"]
 
     @classmethod
-    def _shared_libs(cls):
-        return ["libpypy-c.dll", "libffi-7.dll", "libffi-8.dll"]
+    def _shared_libs(cls, python_dir):
+        # No glob in python2 PathLib
+        for candidate in ["libpypy-c.dll", "libffi-7.dll", "libffi-8.dll"]:
+            dll = python_dir / candidate
+            if dll.exists():
+                yield dll
 
     @classmethod
     def sources(cls, interpreter):
-        for src in super(Pypy2Windows, cls).sources(interpreter):
-            yield src
+        yield from super().sources(interpreter)
         yield PathRefToDest(Path(interpreter.system_prefix) / "libs", dest=lambda self, s: self.dest / s.name)
+
+
+__all__ = [
+    "PyPy2",
+    "PyPy2Posix",
+    "Pypy2Windows",
+]
